@@ -62,7 +62,7 @@ class DBMonitorProvider(object):
         environment = databaseinfra.environment
         sgbd = self.get_sgbd(databaseinfra)
         if sgbd == SGBD_REDIS:
-            instances = databaseinfra.instances.filter(database_type=Instance.REDIS)
+            instances = databaseinfra.instances.filter(instance_type=Instance.REDIS)
         else:
             instances = databaseinfra.instances.all()
         if len(instances) == 1:
